@@ -65,7 +65,6 @@ static void lives_avcodec_unlock(void) {
 }
 
 
-
 static int stream_peek(int fd, unsigned char *str, size_t len) {
   off_t cpos = lseek(fd, 0, SEEK_CUR); // get current posn
   int rv = pread(fd, str, len, cpos); // read len bytes without changing cpos
@@ -77,9 +76,6 @@ static int stream_peek(int fd, unsigned char *str, size_t len) {
 }
 
 
-
-
-
 void get_samps_and_signed(enum AVSampleFormat sfmt, int *asamps, boolean *asigned) {
   *asamps = av_get_bits_per_sample(sfmt);
 
@@ -92,6 +88,7 @@ void get_samps_and_signed(enum AVSampleFormat sfmt, int *asamps, boolean *asigne
   }
 }
 
+
 static int64_t get_current_ticks(void) {
   struct timeval tv;
   gettimeofday(&tv, NULL);
@@ -326,22 +323,14 @@ skip_probe:
 skip_init:
     s = priv->ic->streams[i];
 
+    cc = s->codec;
 
 #ifdef API_3_1
-    cc = avcodec_alloc_context3(NULL);
-    if (!cc) {
-      fprintf(stderr, "avcodec_decoder: out of memory\n");
-      return FALSE;
-    }
-
     ret = avcodec_parameters_to_context(cc, s->codecpar);
     if (ret < 0) {
       fprintf(stderr, "avcodec_decoder: avparms to context failed\n");
       return FALSE;
     }
-
-#else
-    cc = s->codec;
 #endif
 
     // vlc_fourcc_t fcc;
@@ -368,7 +357,11 @@ skip_init:
 
       get_samps_and_signed(cc->sample_fmt, &cdata->asamps, &cdata->asigned);
 
-      sprintf(cdata->audio_name, "%s", cc->codec_name);
+#ifdef HAVE_AVCODEC_GET_NAME
+      sprintf(cdata->audio_name, "%s", avcodec_get_name(cc->codec_id));
+#else
+      sprintf(cdata->audio_name, "%s", cc->codec->name);
+#endif
 
       priv->astream = i;
       break;
@@ -408,7 +401,11 @@ skip_init:
         return FALSE;
       }
 
-      sprintf(cdata->video_name, "%s", cc->codec_name);
+#ifdef HAVE_AVCODEC_GET_NAME
+      sprintf(cdata->video_name, "%s", avcodec_get_name(cc->codec_id));
+#else
+      sprintf(cdata->video_name, "%s", cc->codec->name);
+#endif
 
       cdata->par = cc->sample_aspect_ratio.num / cc->sample_aspect_ratio.den;
       if (cdata->par == 0) cdata->par = 1;
@@ -454,7 +451,7 @@ skip_init:
 
 
     if( strncmp( p_sys->ic->iformat->name, "matroska", 8 ) == 0 &&
-              cc->codec_id == CODEC_ID_DVD_SUBTITLE &&
+              cc->codec_id == AV_CODEC_ID_DVD_SUBTITLE &&
               cc->extradata != NULL &&
               cc->extradata_size > 0 )
     {
@@ -507,7 +504,7 @@ skip_init:
     {
     input_attachment_t *p_attachment;
     psz_type = "attachment";
-    if( cc->codec_id == CODEC_ID_TTF )
+    if( cc->codec_id == AV_CODEC_ID_TTF )
     {
     p_attachment = vlc_input_attachment_New( s->filename, "application/x-truetype-font", NULL,
     cc->extradata, (int)cc->extradata_size );
@@ -536,7 +533,7 @@ skip_init:
     const uint8_t *p_extra = cc->extradata;
     unsigned      i_extra  = cc->extradata_size;
 
-    if( cc->codec_id == CODEC_ID_THEORA && b_ogg )
+    if( cc->codec_id == AV_CODEC_ID_THEORA && b_ogg )
     {
     unsigned pi_size[3];
     void     *pp_data[3];
@@ -560,7 +557,7 @@ skip_init:
     fmt.p_extra = NULL;
     }
     }
-    else if( cc->codec_id == CODEC_ID_SPEEX && b_ogg )
+    else if( cc->codec_id == AV_CODEC_ID_SPEEX && b_ogg )
     {
     uint8_t p_dummy_comment[] = {
     0, 0, 0, 0,
@@ -675,7 +672,7 @@ static void detach_stream(lives_clip_data_t *cdata) {
     av_packet_unref(&priv->packet);
 
   if (priv->pFrame != NULL) {
-    av_frame_unref(&priv->pFrame);
+    av_frame_unref(priv->pFrame);
     priv->pFrame = NULL;
   }
 
@@ -900,7 +897,7 @@ rescan:
 
   cdata->nframes = real_frames;
 
-  if (priv->pFrame != NULL) av_frame_unref(&priv->pFrame);
+  if (priv->pFrame != NULL) av_frame_unref(priv->pFrame);
   priv->pFrame = NULL;
 
   return cdata;
@@ -996,26 +993,16 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
   if (tframe < 0 || tframe >= cdata->nframes || cdata->fps == 0.) return FALSE;
 
-
+  cc = s->codec;
 
 #ifdef API_3_1
-  cc = avcodec_alloc_context3(NULL);
-  if (!cc) {
-    fprintf(stderr, "avcodec_decoder: out of memory\n");
-    return FALSE;
-  }
-
   ret = avcodec_parameters_to_context(cc, s->codecpar);
   if (ret < 0) {
     fprintf(stderr, "avcodec_decoder: avparms to context failed\n");
     return FALSE;
   }
-
-#else
-  cc = s->codec;
 #endif
 
-
   //cc->get_buffer = our_get_buffer;
   //cc->release_buffer = our_release_buffer;
 
@@ -1068,7 +1055,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
     fprintf(stderr, "pt a1 %d %ld\n", priv->last_frame, tframe);
 #endif
 
-    if (priv->pFrame != NULL) av_frame_unref(&priv->pFrame);
+    if (priv->pFrame != NULL) av_frame_unref(priv->pFrame);
     priv->pFrame = NULL;
 
     time = (double)tframe / cdata->fps;
@@ -1163,7 +1150,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
       // otherwise discard this frame
       if (gotFrame) {
         MyPts += (double)AV_TIME_BASE / cdata->fps;
-        av_frame_unref(&priv->pFrame);
+        av_frame_unref(priv->pFrame);
         priv->pFrame = NULL;
       }
 
