@@ -465,7 +465,7 @@ static int flv_get_extradata(lives_clip_data_t *cdata, int size) {
   lives_flv_priv_t *priv = cdata->priv;
 
   av_free(priv->ctx->extradata);
-  priv->ctx->extradata = av_mallocz(size + FF_INPUT_BUFFER_PADDING_SIZE);
+  priv->ctx->extradata = av_mallocz(size + AV_INPUT_BUFFER_PADDING_SIZE);
   if (priv->ctx->extradata == NULL) return AVERROR(ENOMEM);
   priv->ctx->extradata_size = size;
   dummy = read(priv->fd, priv->ctx->extradata, priv->ctx->extradata_size);
@@ -607,7 +607,7 @@ static void detach_stream(lives_clip_data_t *cdata) {
   if (priv->idxc != NULL) idxc_release(cdata);
   priv->idxc = NULL;
 
-  if (priv->picture != NULL) av_frame_unref(&priv->picture);
+  if (priv->picture != NULL) av_frame_unref(priv->picture);
 
   priv->ctx = NULL;
   priv->codec = NULL;
@@ -996,17 +996,17 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
       switch (vcodec) {
       case FLV_CODECID_H263  :
         sprintf(cdata->video_name, "%s", "flv1");
-        codec = avcodec_find_decoder(CODEC_ID_FLV1);
+        codec = avcodec_find_decoder(AV_CODEC_ID_FLV1);
         priv->pack_offset = 1;
         break;
       case FLV_CODECID_SCREEN:
         sprintf(cdata->video_name, "%s", "flashsv");
-        codec = avcodec_find_decoder(CODEC_ID_FLASHSV);
+        codec = avcodec_find_decoder(AV_CODEC_ID_FLASHSV);
         priv->pack_offset = 1;
         break;
       case FLV_CODECID_SCREEN2:
         sprintf(cdata->video_name, "%s", "flashsv2");
-        codec = avcodec_find_decoder(CODEC_ID_FLASHSV2);
+        codec = avcodec_find_decoder(AV_CODEC_ID_FLASHSV2);
         priv->pack_offset = 1;
         break;
       case FLV_CODECID_VP6   :
@@ -1015,11 +1015,11 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
         cdata->offs_y = (pack.data[1] & 0XF0) >> 5; // divide by 2 for offset
         if (cdata->width == 0) cdata->width = pack.data[7] * 16 - cdata->offs_x * 2;
         if (cdata->height == 0) cdata->height = pack.data[6] * 16 - cdata->offs_y * 2;
-        codec = avcodec_find_decoder(CODEC_ID_VP6F);
+        codec = avcodec_find_decoder(AV_CODEC_ID_VP6F);
         priv->pack_offset = 2;
         break;
       case FLV_CODECID_VP6A  :
-        codec = avcodec_find_decoder(CODEC_ID_VP6A);
+        codec = avcodec_find_decoder(AV_CODEC_ID_VP6A);
         priv->ctx = ctx = avcodec_alloc_context3(codec);
 
         sprintf(cdata->video_name, "%s", "vp6a");
@@ -1038,7 +1038,7 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
       case FLV_CODECID_H264:
         // broken....
         sprintf(cdata->video_name, "%s", "h264");
-        codec = avcodec_find_decoder(CODEC_ID_H264);
+        codec = avcodec_find_decoder(AV_CODEC_ID_H264);
         priv->pack_offset = 5;
         break;
       default:
@@ -1143,12 +1143,12 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
 
   if (isclone) return TRUE;
 
-  pack.data = malloc(pack.size - priv->pack_offset + FF_INPUT_BUFFER_PADDING_SIZE);
+  pack.data = malloc(pack.size - priv->pack_offset + AV_INPUT_BUFFER_PADDING_SIZE);
 
   av_init_packet(&priv->avpkt);
 
   priv->avpkt.size = read(priv->fd, pack.data, pack.size - priv->pack_offset);
-  memset(pack.data + priv->avpkt.size, 0, FF_INPUT_BUFFER_PADDING_SIZE);
+  memset(pack.data + priv->avpkt.size, 0, AV_INPUT_BUFFER_PADDING_SIZE);
   priv->input_position += pack.size + 4;
   priv->avpkt.data = pack.data;
   priv->avpkt.dts = priv->avpkt.pts = pack.dts;
@@ -1206,10 +1206,10 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
             continue;
           }
 
-          pack.data = malloc(pack.size - priv->pack_offset + FF_INPUT_BUFFER_PADDING_SIZE);
+          pack.data = malloc(pack.size - priv->pack_offset + AV_INPUT_BUFFER_PADDING_SIZE);
           if (priv->pack_offset != 5) lseek(priv->fd, priv->pack_offset - 5, SEEK_CUR);
           priv->avpkt.size = read(priv->fd, pack.data, pack.size - priv->pack_offset);
-          memset(pack.data + priv->avpkt.size, 0, FF_INPUT_BUFFER_PADDING_SIZE);
+          memset(pack.data + priv->avpkt.size, 0, AV_INPUT_BUFFER_PADDING_SIZE);
           priv->avpkt.data = pack.data;
           break;
         }
@@ -1455,7 +1455,7 @@ static lives_clip_data_t *flv_clone(lives_clip_data_t *cdata) {
 
   }
 
-  if (dpriv->picture != NULL) av_frame_unref(&dpriv->picture);
+  if (dpriv->picture != NULL) av_frame_unref(dpriv->picture);
   dpriv->picture = NULL;
 
   dpriv->last_frame = -1;
@@ -1537,7 +1537,7 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
   cdata->asigned = TRUE;
   cdata->ainterleaf = TRUE;
 
-  if (priv->picture != NULL) av_frame_unref(&priv->picture);
+  if (priv->picture != NULL) av_frame_unref(priv->picture);
   priv->picture = NULL;
 
   if (cdata->width != cdata->frame_width || cdata->height != cdata->frame_height)
@@ -1709,12 +1709,12 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
         continue;
       }
 
-      pack.data = malloc(pack.size - priv->pack_offset + FF_INPUT_BUFFER_PADDING_SIZE);
+      pack.data = malloc(pack.size - priv->pack_offset + AV_INPUT_BUFFER_PADDING_SIZE);
 
       if (priv->pack_offset != 1) lseek(priv->fd, priv->pack_offset - 1, SEEK_CUR);
 
       priv->avpkt.size = read(priv->fd, pack.data, pack.size - priv->pack_offset);
-      memset(pack.data + priv->avpkt.size, 0, FF_INPUT_BUFFER_PADDING_SIZE);
+      memset(pack.data + priv->avpkt.size, 0, AV_INPUT_BUFFER_PADDING_SIZE);
       priv->avpkt.data = pack.data;
       priv->avpkt.dts = priv->avpkt.pts = pack.dts;
 
