@@ -19,10 +19,10 @@
 
 ///////////////////////////////////////////////////////////////////
 
-static int num_versions=2; // number of different weed api versions supported
-static int api_versions[]= {131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
+static int num_versions = 2; // number of different weed api versions supported
+static int api_versions[] = {131, 100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
 
-static int package_version=1; // version of this package
+static int package_version = 1; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
@@ -83,13 +83,13 @@ static void init_RGB_to_YCbCr_tables(void) {
    */
   for (i = 0; i < 256; i++) {
     Y_R[i] = myround(0.299 * (double)i
-                     * 219.0 / 255.0 * (double)(1<<FP_BITS));
+                     * 219.0 / 255.0 * (double)(1 << FP_BITS));
     Y_G[i] = myround(0.587 * (double)i
-                     * 219.0 / 255.0 * (double)(1<<FP_BITS));
+                     * 219.0 / 255.0 * (double)(1 << FP_BITS));
     Y_B[i] = myround((0.114 * (double)i
-                      * 219.0 / 255.0 * (double)(1<<FP_BITS))
-                     + (double)(1<<(FP_BITS-1))
-                     + (16.0 * (double)(1<<FP_BITS)));
+                      * 219.0 / 255.0 * (double)(1 << FP_BITS))
+                     + (double)(1 << (FP_BITS - 1))
+                     + (16.0 * (double)(1 << FP_BITS)));
 
   }
 }
@@ -97,17 +97,17 @@ static void init_RGB_to_YCbCr_tables(void) {
 
 static inline uint8_t
 calc_luma(uint8_t *pixel) {
-  return (Y_R[pixel[2]] + Y_G[pixel[1]]+ Y_B[pixel[0]]) >> FP_BITS;
+  return (Y_R[pixel[2]] + Y_G[pixel[1]] + Y_B[pixel[0]]) >> FP_BITS;
 }
 
 
 int bumpmap_init(weed_plant_t *inst) {
-  _sdata *sdata=(_sdata *)weed_malloc(sizeof(_sdata));
-  if (sdata==NULL) return WEED_ERROR_MEMORY_ALLOCATION;
+  _sdata *sdata = (_sdata *)weed_malloc(sizeof(_sdata));
+  if (sdata == NULL) return WEED_ERROR_MEMORY_ALLOCATION;
 
-  sdata->sin_index=0;
-  sdata->sin_index2=80;
-  weed_set_voidptr_value(inst,"plugin_internal",sdata);
+  sdata->sin_index = 0;
+  sdata->sin_index2 = 80;
+  weed_set_voidptr_value(inst, "plugin_internal", sdata);
 
   return WEED_NO_ERROR;
 }
@@ -115,10 +115,10 @@ int bumpmap_init(weed_plant_t *inst) {
 
 int bumpmap_deinit(weed_plant_t *inst) {
   int error;
-  _sdata *sdata=weed_get_voidptr_value(inst,"plugin_internal",&error);
-  if (sdata!=NULL) {
+  _sdata *sdata = weed_get_voidptr_value(inst, "plugin_internal", &error);
+  if (sdata != NULL) {
     weed_free(sdata);
-    weed_set_voidptr_value(inst,"plugin_internal",NULL);
+    weed_set_voidptr_value(inst, "plugin_internal", NULL);
   }
 
   return WEED_NO_ERROR;
@@ -127,16 +127,17 @@ int bumpmap_deinit(weed_plant_t *inst) {
 
 int bumpmap_process(weed_plant_t *inst, weed_timecode_t timestamp) {
   int error;
-  weed_plant_t *in_channel=weed_get_plantptr_value(inst,"in_channels",&error),*out_channel=weed_get_plantptr_value(inst,"out_channels",
-                           &error);
-  unsigned char *src=weed_get_voidptr_value(in_channel,"pixel_data",&error);
-  unsigned char *dst=weed_get_voidptr_value(out_channel,"pixel_data",&error);
-  int width=weed_get_int_value(in_channel,"width",&error);
-  int height=weed_get_int_value(in_channel,"height",&error);
-  int irowstride=weed_get_int_value(in_channel,"rowstrides",&error);
-  int orowstride=weed_get_int_value(out_channel,"rowstrides",&error);
-  int width3=width*3;
-  _sdata *sdata=weed_get_voidptr_value(inst,"plugin_internal",&error);
+  weed_plant_t *in_channel = weed_get_plantptr_value(inst, "in_channels", &error), *out_channel = weed_get_plantptr_value(inst,
+                             "out_channels",
+                             &error);
+  unsigned char *src = weed_get_voidptr_value(in_channel, "pixel_data", &error);
+  unsigned char *dst = weed_get_voidptr_value(out_channel, "pixel_data", &error);
+  int width = weed_get_int_value(in_channel, "width", &error);
+  int height = weed_get_int_value(in_channel, "height", &error);
+  int irowstride = weed_get_int_value(in_channel, "rowstrides", &error);
+  int orowstride = weed_get_int_value(out_channel, "rowstrides", &error);
+  int width3 = width * 3;
+  _sdata *sdata = weed_get_voidptr_value(inst, "plugin_internal", &error);
 
   uint16_t lightx, lighty, temp;
   short normalx, normaly, x, y;
@@ -147,23 +148,23 @@ int bumpmap_process(weed_plant_t *inst, weed_timecode_t timestamp) {
   /* create bump map */
   for (x = 0; x < width - 1; x++) {
     for (y = 1; y < height - 1; y++) {
-      bumpmap[x][y].x = calc_luma(&src[y*irowstride+x*3+3])-calc_luma(&src[y*irowstride+x*3]);
-      bumpmap[x][y].y = calc_luma(&src[y*irowstride+x*3])-calc_luma(&src[(y-1)*irowstride+x*3]);
+      bumpmap[x][y].x = calc_luma(&src[y * irowstride + x * 3 + 3]) - calc_luma(&src[y * irowstride + x * 3]);
+      bumpmap[x][y].y = calc_luma(&src[y * irowstride + x * 3]) - calc_luma(&src[(y - 1) * irowstride + x * 3]);
     }
   }
 
   lightx = aSin[sdata->sin_index];
   lighty = aSin[sdata->sin_index2];
 
-  weed_memset(dst,0,orowstride);
+  weed_memset(dst, 0, orowstride);
   s1 = dst + orowstride;
 
-  orowstride-=width3-3;
+  orowstride -= width3 - 3;
 
   for (y = 1; y < height - 1; ++y) {
     temp = lighty - y;
-    weed_memset(s1,0,3);
-    s1+=3;
+    weed_memset(s1, 0, 3);
+    s1 += 3;
 
     for (x = 1; x < width - 1; x++) {
       normalx = bumpmap[x][y].x + lightx - x;
@@ -178,14 +179,14 @@ int bumpmap_process(weed_plant_t *inst, weed_timecode_t timestamp) {
       else if (normaly > 255)
         normaly = 0;
 
-      weed_memset(s1,reflectionmap[normalx][normaly],3);
-      s1+=3;
+      weed_memset(s1, reflectionmap[normalx][normaly], 3);
+      s1 += 3;
     }
-    weed_memset(s1,0,3);
-    s1+=orowstride;
+    weed_memset(s1, 0, 3);
+    s1 += orowstride;
   }
 
-  weed_memset(s1,0,orowstride+width3-3);
+  weed_memset(s1, 0, orowstride + width3 - 3);
 
   sdata->sin_index += 3;
   sdata->sin_index &= 511;
@@ -225,18 +226,19 @@ void bumpmap_x_init(void) {
 
 
 weed_plant_t *weed_setup(weed_bootstrap_f weed_boot) {
-  weed_plant_t *plugin_info=weed_plugin_info_init(weed_boot,num_versions,api_versions);
-  if (plugin_info!=NULL) {
-    int palette_list[]= {WEED_PALETTE_BGR24,WEED_PALETTE_RGB24,WEED_PALETTE_END};
+  weed_plant_t *plugin_info = weed_plugin_info_init(weed_boot, num_versions, api_versions);
+  if (plugin_info != NULL) {
+    int palette_list[] = {WEED_PALETTE_BGR24, WEED_PALETTE_RGB24, WEED_PALETTE_END};
 
-    weed_plant_t *in_chantmpls[]= {weed_channel_template_init("in channel 0",0,palette_list),NULL};
-    weed_plant_t *out_chantmpls[]= {weed_channel_template_init("out channel 0",WEED_CHANNEL_CAN_DO_INPLACE,palette_list),NULL};
-    weed_plant_t *filter_class=weed_filter_class_init("bumpmap","salsaman",1,0,&bumpmap_init,&bumpmap_process,&bumpmap_deinit,in_chantmpls,
-                               out_chantmpls,NULL,NULL);
+    weed_plant_t *in_chantmpls[] = {weed_channel_template_init("in channel 0", 0, palette_list), NULL};
+    weed_plant_t *out_chantmpls[] = {weed_channel_template_init("out channel 0", WEED_CHANNEL_CAN_DO_INPLACE, palette_list), NULL};
+    weed_plant_t *filter_class = weed_filter_class_init("bumpmap", "salsaman", 1, 0, &bumpmap_init, &bumpmap_process, &bumpmap_deinit,
+                                 in_chantmpls,
+                                 out_chantmpls, NULL, NULL);
 
-    weed_plugin_info_add_filter_class(plugin_info,filter_class);
+    weed_plugin_info_add_filter_class(plugin_info, filter_class);
 
-    weed_set_int_value(plugin_info,"version",package_version);
+    weed_set_int_value(plugin_info, "version", package_version);
 
     bumpmap_x_init();
     init_RGB_to_YCbCr_tables();
