@@ -63,8 +63,6 @@ typedef struct _aserver_message_t {
   volatile struct _aserver_message_t *next;
 } aserver_message_t;
 
-
-
 typedef enum {
   LIVES_NOP_OPERATION = 0,
   LIVES_READ_OPERATION,
@@ -72,9 +70,6 @@ typedef enum {
   LIVES_CONVERT_OPERATION
 } lives_operation_t;
 
-
-
-
 typedef struct {
   lives_operation_t operation; // read, write, or convert [readonly by server]
   volatile boolean is_ready; // [readwrite all]
@@ -104,6 +99,7 @@ typedef struct {
 
   size_t samp_space; ///< buffer space in samples (* by sizeof(type) to get bytesize) [if interleaf, also * by chans]
 
+  boolean sequential; ///< hint that we will read sequentially starting from seek
 
   // in or out buffers
   uint8_t **buffer8; ///< sample data in 8 bit format (or NULL)
@@ -124,7 +120,6 @@ typedef struct {
   size_t samples_filled; ///< number of samples filled (readonly client)
   size_t start_sample; ///< used for reading (readonly server)
 
-
   // private fields (used by server)
   uint8_t *_filebuffer; ///< raw data to/from file - can be cast to int16_t
   ssize_t _cbytesize; ///< current _filebuffer bytesize; if this changes we need to realloc _filebuffer
@@ -140,7 +135,6 @@ typedef struct {
   volatile boolean die;  ///< set to TRUE to shut down thread
 } lives_audio_buf_t;
 
-
 //////////////////////////////////////////
 
 typedef enum lives_audio_loop {
@@ -149,11 +143,12 @@ typedef enum lives_audio_loop {
   AUDIO_LOOP_PINGPONG
 } lives_audio_loop_t;
 
-
 float get_float_audio_val_at_time(int fnum, int afd, double secs, int chnum, int chans);
 
 void sample_silence_dS(float *dst, uint64_t nsamples);
 
+void sample_silence_stream(int nchans, int nframes);
+
 void sample_move_d8_d16(short *dst, uint8_t *src,
                         uint64_t nsamples, size_t tbytes, float scale, int nDstChannels, int nSrcChannels, int swap_sign);
 
@@ -163,7 +158,7 @@ void sample_move_d16_d16(short *dst, short *src,
 void sample_move_d16_d8(uint8_t *dst, short *src,
                         uint64_t nsamples, size_t tbytes, float scale, int nDstChannels, int nSrcChannels, int swap_sign);
 
-void sample_move_d16_float(float *dst, short *src, uint64_t nsamples, uint64_t src_skip, int is_unsigned, boolean rev_endian, float vol);
+float sample_move_d16_float(float *dst, short *src, uint64_t nsamples, uint64_t src_skip, int is_unsigned, boolean rev_endian, float vol);
 
 int64_t sample_move_float_int(void *holding_buff, float **float_buffer, int nsamps, float scale, int chans, int asamps, int usigned,
                               boolean swap_endian, boolean float_interleaved, float vol); ///< returns frames output
@@ -202,10 +197,8 @@ void pulse_rec_audio_end(boolean close_dev, boolean close_fd);
 
 void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_plant_t *st_event, boolean exact);
 
-
 boolean resync_audio(int frameno);
 
-
 lives_audio_track_state_t *get_audio_and_effects_state_at(weed_plant_t *event_list, weed_plant_t *st_event, boolean get_audstate,
     boolean exact);
 
@@ -239,4 +232,6 @@ void stop_audio_stream(void);
 void clear_audio_stream(void);
 void audio_stream(void *buff, size_t nbytes, int fd);
 
+char *lives_get_audio_file_name(int fnum);
+
 #endif
