@@ -4,7 +4,6 @@
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
-
 #ifndef HAS_LIVES_EFFECTS_WEED_H
 #define HAS_LIVES_EFFECTS_WEED_H
 
@@ -36,19 +35,37 @@ typedef enum {
   FILTER_INFO_REINITED = 512
 } lives_filter_error_t;
 
-
 typedef enum {
   FX_LIST_NAME,
   FX_LIST_NAME_AND_TYPE,
   FX_LIST_HASHNAME,
 } lives_fx_list_t;
 
+#ifndef WEED_PLANT_LAYER
+#define WEED_PLANT_LAYER WEED_PLANT_CHANNEL
+#endif
+
 #define WEED_LEAF_TYPE "type"
 #define WEED_LEAF_PLUGIN_INFO "plugin_info"
 #define WEED_LEAF_FILTERS "filters"
 #define WEED_LEAF_MAINTAINER "maintainer"
 #define WEED_LEAF_HOST_INFO "host_info"
 
+// host info
+#define WEED_LEAF_API_VERSION "api_version"
+#define WEED_LEAF_GET_FUNC "weed_leaf_get_func"
+#define WEED_LEAF_SET_FUNC "weed_leaf_set_func"
+#define WEED_PLANT_NEW_FUNC "weed_plant_new_func"
+#define WEED_PLANT_LIST_LEAVES_FUNC "weed_plant_list_leaves_func"
+#define WEED_LEAF_NUM_ELEMENTS_FUNC "weed_leaf_num_elements_func"
+#define WEED_LEAF_ELEMENT_SIZE_FUNC "weed_leaf_element_size_func"
+#define WEED_LEAF_SEED_TYPE_FUNC "weed_leaf_seed_type_func"
+#define WEED_LEAF_GET_FLAGS_FUNC "weed_leaf_get_flags_func"
+#define WEED_LEAF_MALLOC_FUNC "weed_malloc_func"
+#define WEED_LEAF_FREE_FUNC "weed_free_func"
+#define WEED_LEAF_MEMSET_FUNC "weed_memset_func"
+#define WEED_LEAF_MEMCPY_FUNC "weed_memcpy_func"
+
 // filter_class
 #define WEED_LEAF_INIT_FUNC "init_func"
 #define WEED_LEAF_DEINIT_FUNC "deinit_func"
@@ -117,7 +134,6 @@ typedef enum {
 #define WEED_LEAF_TRANSITION "transition"
 #define WEED_LEAF_IS_VOLUME_MASTER "is_volume_master"
 
-
 // audio
 #define WEED_LEAF_IS_AUDIO "is_audio"
 #define WEED_LEAF_AUDIO_DATA "audio_data"
@@ -143,11 +159,9 @@ typedef enum {
 #define WEED_LEAF_RFX_STRINGS "rfx_strings"
 #define WEED_LEAF_RFX_DELIM "rfx_delim"
 
-
 // plugin specific values
 #define WEED_LEAF_PLUGIN_UNSTABLE "plugin_unstable" // plugin hint to host
 
-
 // internal values
 #define WEED_LEAF_HOST_AUDIO_PLAYER "host_audio_player" // exported to plugins
 
@@ -182,12 +196,10 @@ typedef enum {
 #define WEED_LEAF_CLIP "clip"
 #define WEED_LEAF_FRAME "frame"
 
-
-
 /// bootstrap function for weed plugins
 weed_plant_t *weed_bootstrap_func(weed_default_getter_f *value, int num_versions, int *plugin_versions);
 
-weed_plant_t *get_weed_filter(int filter_idx);
+weed_plant_t *get_weed_filter(int filter_idx); // TODO: make const
 char *weed_filter_idx_get_name(int filter_idx) WARN_UNUSED;
 char *weed_instance_get_filter_name(weed_plant_t *inst, boolean get_compound_parent) WARN_UNUSED;
 char *make_weed_hashname(int filter_idx, boolean fullname,
@@ -250,7 +262,6 @@ void add_param_connections(weed_plant_t *inst);
 lives_filter_error_t weed_reinit_effect(weed_plant_t *inst, boolean reinit_compound);
 void weed_reinit_all(void);
 
-
 int weed_flagset_array_count(weed_plant_t **array, boolean set_readonly);
 
 int num_alpha_channels(weed_plant_t *filter, boolean out);
@@ -271,7 +282,6 @@ boolean is_perchannel_multiw(weed_plant_t *param);
 boolean has_perchannel_multiw(weed_plant_t *filter);
 boolean weed_parameter_has_variable_elements_strict(weed_plant_t *inst, weed_plant_t *ptmpl);
 
-
 /// parameter interpolation
 boolean interpolate_param(weed_plant_t *inst, int i, void *pchain, weed_timecode_t tc);
 boolean interpolate_params(weed_plant_t *inst, void **pchains, weed_timecode_t tc);
@@ -282,7 +292,6 @@ void filter_mutex_unlock(int key); // 0 based key
 boolean weed_plant_serialise(int fd, weed_plant_t *plant, unsigned char **mem);
 weed_plant_t *weed_plant_deserialise(int fd, unsigned char **mem);
 
-
 /// record a parameter value change in our event_list
 void rec_param_change(weed_plant_t *inst, int pnum);
 
@@ -314,17 +323,25 @@ lives_filter_error_t weed_apply_audio_instance(weed_plant_t *init_event, float *
     double arate, weed_timecode_t tc, double *vis);
 
 boolean weed_generator_start(weed_plant_t *inst, int key);  // 0 based key
-weed_plant_t *weed_layer_new_from_generator(weed_plant_t *inst, weed_timecode_t tc);
 void weed_generator_end(weed_plant_t *inst);
 boolean weed_playback_gen_start(void);
 void weed_bg_generator_end(weed_plant_t *inst);
 void wge_inner(weed_plant_t *inst, boolean unref); ///< deinit instance(s) for generator
 
+// layers
+weed_plant_t *weed_layer_create_from_generator(weed_plant_t *inst, weed_timecode_t tc);
+weed_plant_t *weed_layer_new();
+weed_plant_t *weed_layer_new_for_frame();
+void **weed_layer_get_pixel_data(weed_plant_t *layer);
+int *weed_layer_get_rowstrides(weed_plant_t *layer);
+int weed_layer_get_width(weed_plant_t *layer);
+int weed_layer_get_height(weed_plant_t *layer);
+int weed_layer_current_palette(weed_plant_t *layer);
+
 /// for multitrack
 void backup_weed_instances(void);
 void restore_weed_instances(void);
 
-
 //////////////////////////////////////////////////////////
 // WARNING !! "key" here starts at 1, "mode" starts at 0
 
@@ -354,15 +371,12 @@ int rte_key_getmaxmode(int key); ///< returns highest mode which is set
 
 weed_plant_t *get_new_inst_for_keymode(int key, int mode); ///< get new inst (during recording playback)
 
-
 boolean rte_key_setmode(int key, int newmode);  ///< set mode for a given key; if key==0 then the active key is used
 
 ///< returns -1 if the filter is not found; it will match the first name found - returns -2 if you try to switch a generator/non-generator
 int rte_switch_keymode(int key, int mode, const char *hashname);
 
-boolean rte_key_is_enabled(int key);
-
-
+//boolean rte_key_is_enabled(int key);
 
 /////////////////////////////////////////////////////////////
 
@@ -381,12 +395,10 @@ boolean read_key_defaults(int fd, int nparams, int key, int mode, int version);
 void set_key_defaults(weed_plant_t *inst, int key, int mode);
 boolean has_key_defaults(void);
 
-
 //////////////////////////////////////////////////////
 // 0 based keys
 void rte_swap_fg_bg(void);
 
-
 int rte_bg_gen_key(void) GNU_PURE;
 
 int rte_fg_gen_key(void) GNU_PURE;
@@ -394,8 +406,6 @@ int rte_fg_gen_key(void) GNU_PURE;
 int rte_bg_gen_mode(void) GNU_PURE;
 int rte_fg_gen_mode(void) GNU_PURE;
 
-
-
 ////////////////////////////////////////////////////////////////////////
 
 char *get_weed_display_string(weed_plant_t *inst, int pnum);
@@ -421,7 +431,6 @@ void update_host_info(weed_plant_t *inst);
 /// add default filler values to a parameter or pchange.
 void fill_param_vals_to(weed_plant_t *param, weed_plant_t *ptmpl, int fill_slot);
 
-
 // some general utilities
 
 #define WEED_PLANT_IS_PLUGIN_INFO(plant) (weed_get_plant_type(plant) == WEED_PLANT_PLUGIN_INFO ? 1 : 0)
@@ -434,5 +443,6 @@ void fill_param_vals_to(weed_plant_t *param, weed_plant_t *ptmpl, int fill_slot)
 #define WEED_PLANT_IS_PARAMETER_TEMPLATE(plant) (weed_get_plant_type(plant) == WEED_PLANT_PARAMETER_TEMPLATE ? 1 : 0)
 #define WEED_PLANT_IS_GUI(plant) (weed_get_plant_type(plant) == WEED_PLANT_GUI ? 1 : 0)
 
+int weed_general_error;
 
 #endif
