@@ -1,6 +1,6 @@
 // interface.h
 // LiVES
-// (c) G. Finch 2003 - 2016 <salsaman@gmail.com>
+// (c) G. Finch 2003 - 2018 <salsaman+lives@gmail.com>
 // Released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -40,7 +40,6 @@ typedef struct {
 
 lives_clipinfo_t *create_clip_info_window(int audio_channels, boolean is_mt);
 
-
 typedef struct {
   LiVESWidget *dialog;
   LiVESWidget *entry;
@@ -64,7 +63,6 @@ typedef struct __insertw {
 
 _insertw *create_insert_dialog(void);
 
-
 typedef struct __commentsw {
   LiVESWidget *comments_dialog;
   LiVESWidget *title_entry;
@@ -76,7 +74,6 @@ typedef struct __commentsw {
 
 _commentsw *create_comments_dialog(lives_clip_t *sfile, char *filename);
 
-
 typedef struct {
   LiVESWidget *dialog;
   LiVESWidget *clear_button;
@@ -87,14 +84,12 @@ typedef struct {
 
 text_window *create_text_window(const char *title_part, const char *text, LiVESTextBuffer *);
 
-
 typedef struct {
   LiVESWidget *dialog;
   LiVESWidget *time_spin;
   boolean is_sel;
 } aud_dialog_t;
 
-
 typedef struct {
   boolean use_advanced;
   LiVESWidget *advbutton;
@@ -108,7 +103,6 @@ typedef struct {
   LiVESWidget *radiobuttond;
 } lives_tvcardw_t;
 
-
 #define LIVES_PREVIEW_TYPE_VIDEO_AUDIO 1
 #define LIVES_PREVIEW_TYPE_AUDIO_ONLY 2
 #define LIVES_PREVIEW_TYPE_RANGE 3
@@ -121,7 +115,6 @@ typedef struct {
 #define LIVES_FILE_SELECTION_VIDEO_RANGE 4
 #define LIVES_FILE_SELECTION_IMAGE_ONLY 5
 
-
 aud_dialog_t *create_audfade_dialog(int type);
 LiVESWidget *create_combo_dialog(int type, livespointer user_data);
 
@@ -135,23 +128,32 @@ void make_preview_box(void);
 void play_window_set_title(void);
 void add_to_playframe(void);
 LiVESWidget *create_cdtrack_dialog(int type, livespointer user_data);
+
+typedef struct {
+  LiVESWidget *dialog;
+  LiVESWidget *atrigger_button;
+  LiVESWidget *atrigger_spin;
+  LiVESWidget *apb_button;
+  LiVESWidget *mute_button;
+  LiVESWidget *debug_button;
+} autolives_window;
+
+autolives_window *autolives_pre_dialog(void);
+
 LiVESTextView *create_output_textview(void);
 char *choose_file(const char *dir, const char *fname, char **const filt, LiVESFileChooserAction act, const char *title, LiVESWidget *extra);
 LiVESWidget *choose_file_with_preview(const char *dir, const char *title, char **const filt, int preview_type);
 void add_suffix_check(LiVESBox *box, const char *ext);
 
-
 _commentsw *commentsw;
 _entryw *renamew;
 _entryw *locw;
 _insertw *insertw;
 text_window *textwindow;
 
-
 #define DEF_AUD_FADE_SECS 10. ///< default time to offer fade audio in/out for
 
-
-#define MIN_MSGBOX_WIDTH ((int)(GUI_SCREEN_WIDTH > 1024 ? (820. * widget_opts.scale) : 600))
+#define MIN_MSGBOX_WIDTH ((int)(620. * widget_opts.scale))
 
 // textboxes for clip info
 #define TB_WIDTH ((int)(200.*widget_opts.scale))
