@@ -252,6 +252,9 @@ static void push_cache_buffer(lives_audio_buf_t *cache_buffer, jack_driver_t *ja
                               size_t in_bytes, size_t nframes, double shrink_factor) {
   // push a cache_buffer for another thread to fill
 
+  if (mainw->ascrap_file > -1 && jackd->playing_file == mainw->ascrap_file) cache_buffer->sequential = TRUE;
+  else cache_buffer->sequential = FALSE;
+
   cache_buffer->fileno = jackd->playing_file;
   cache_buffer->seek = jackd->seek_pos;
   cache_buffer->bytesize = in_bytes;
@@ -260,7 +263,7 @@ static void push_cache_buffer(lives_audio_buf_t *cache_buffer, jack_driver_t *ja
   cache_buffer->out_achans = jackd->num_output_channels;
 
   cache_buffer->in_asamps = afile->asampsize;
-  cache_buffer->out_asamps = -32;  ///< 32 bit float
+  cache_buffer->out_asamps = -32;  ///< 32 bit float :: TODO - should this be 16, since
 
   cache_buffer->shrink_factor = shrink_factor;
 
@@ -277,12 +280,9 @@ static void push_cache_buffer(lives_audio_buf_t *cache_buffer, jack_driver_t *ja
 }
 
 
-static lives_audio_buf_t *pop_cache_buffer(void) {
+LIVES_INLINE lives_audio_buf_t *pop_cache_buffer(void) {
   // get next available cache_buffer
-
-  lives_audio_buf_t *cache_buffer = audio_cache_get_buffer();
-  if (cache_buffer != NULL) return cache_buffer;
-  return NULL;
+  return audio_cache_get_buffer();
 }
 
 
@@ -365,6 +365,9 @@ static int audio_process(nframes_t nframes, void *arg) {
             append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
           }
         }
+        if (!jackd->is_silent && mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+          sample_silence_stream(jackd->num_output_channels, nframes);
+        }
         if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
           mainw->audio_frame_buffer->samples_filled += nframes;
           pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -416,6 +419,9 @@ static int audio_process(nframes_t nframes, void *arg) {
             append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
           }
         }
+        if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+          sample_silence_stream(jackd->num_output_channels, nframes);
+        }
         if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
           mainw->audio_frame_buffer->samples_filled += nframes;
           pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -499,9 +505,9 @@ static int audio_process(nframes_t nframes, void *arg) {
               }
             }
 
-            if (!wait_cache_buffer && ((mainw->agen_key == 0 && !mainw->agen_needs_reinit) || mainw->multitrack != NULL))
+            if (!wait_cache_buffer && ((mainw->agen_key == 0 && !mainw->agen_needs_reinit) || mainw->multitrack != NULL)) {
               push_cache_buffer(cache_buffer, jackd, in_bytes, nframes, shrink_factor);
-
+            }
             if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
               pthread_mutex_lock(&mainw->abuf_frame_mutex);
             }
@@ -511,6 +517,9 @@ static int audio_process(nframes_t nframes, void *arg) {
                 append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
               }
             }
+            if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+              sample_silence_stream(jackd->num_output_channels, nframes);
+            }
             if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
               mainw->audio_frame_buffer->samples_filled += nframes;
               pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -577,6 +586,9 @@ static int audio_process(nframes_t nframes, void *arg) {
               append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
             }
           }
+          if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+            sample_silence_stream(jackd->num_output_channels, nframes);
+          }
           if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
             mainw->audio_frame_buffer->samples_filled += nframes;
             pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -626,7 +638,8 @@ static int audio_process(nframes_t nframes, void *arg) {
       if (numFramesToWrite) {
         if (!from_memory) {
           //	if (((int)(jackd->num_calls/100.))*100==jackd->num_calls) if (mainw->soft_debug) g_print("audio pip\n");
-          if ((mainw->agen_key != 0 || mainw->agen_needs_reinit || cache_buffer->bufferf != NULL) && !jackd->mute) {
+          if ((mainw->agen_key != 0 || mainw->agen_needs_reinit || cache_buffer->bufferf != NULL) &&
+              !jackd->mute) { // TODO - try buffer16 instead of bufferf
             float *fbuffer = NULL;
 
             if (mainw->agen_key != 0 || mainw->agen_needs_reinit) {
@@ -651,9 +664,12 @@ static int audio_process(nframes_t nframes, void *arg) {
                   for (i = 0; i < jackd->num_output_channels; i++) {
                     sample_silence_dS(out_buffer[i], numFramesToWrite);
                     if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
-                      append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
+                      append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], numFramesToWrite, i);
                     }
                   }
+                  if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+                    sample_silence_stream(jackd->num_output_channels, numFramesToWrite);
+                  }
                   if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
                     mainw->audio_frame_buffer->samples_filled += numFramesToWrite;
                     pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -676,7 +692,7 @@ static int audio_process(nframes_t nframes, void *arg) {
               }
 
               if (!pl_error && has_audio_filters(AF_TYPE_ANY)) {
-                uint64_t tc = jackd->audio_ticks + (uint64_t)(jackd->frames_written / (double)jackd->sample_out_rate * U_SEC);
+                uint64_t tc = jackd->audio_ticks + (uint64_t)(jackd->frames_written / (double)jackd->sample_out_rate * TICKS_PER_SECOND_DBL);
                 // apply any audio effects with in_channels
                 weed_apply_audio_effects_rt(out_buffer, jackd->num_output_channels, numFramesToWrite, jackd->sample_out_rate, tc, FALSE);
               }
@@ -693,12 +709,12 @@ static int audio_process(nframes_t nframes, void *arg) {
 
             } else {
               for (i = 0; i < jackd->num_output_channels; i++) {
-                sample_move_d16_float(out_buffer[i], cache_buffer->buffer16[0] + i, numFramesToWrite,
-                                      jackd->num_output_channels, afile->signed_endian & AFORM_UNSIGNED, FALSE, vol);
+                jackd->abs_maxvol_heard = sample_move_d16_float(out_buffer[i], cache_buffer->buffer16[0] + i, numFramesToWrite,
+                                          jackd->num_output_channels, afile->signed_endian & AFORM_UNSIGNED, FALSE, vol);
               }
 
               if (has_audio_filters(AF_TYPE_ANY) && jackd->playing_file != mainw->ascrap_file) {
-                uint64_t tc = jackd->audio_ticks + (uint64_t)(jackd->frames_written / (double)jackd->sample_out_rate * U_SEC);
+                uint64_t tc = jackd->audio_ticks + (uint64_t)(jackd->frames_written / (double)jackd->sample_out_rate * TICKS_PER_SECOND_DBL);
                 // apply any audio effects with in_channels
                 weed_apply_audio_effects_rt(out_buffer, jackd->num_output_channels, numFramesToWrite, jackd->sample_out_rate, tc, FALSE);
               }
@@ -782,6 +798,9 @@ static int audio_process(nframes_t nframes, void *arg) {
                 append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
               }
             }
+            if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+              sample_silence_stream(jackd->num_output_channels, numFramesToWrite);
+            }
             if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
               mainw->audio_frame_buffer->samples_filled += numFramesToWrite;
               pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -818,6 +837,9 @@ static int audio_process(nframes_t nframes, void *arg) {
                       append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
                     }
                   }
+                  if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+                    sample_silence_stream(jackd->num_output_channels, numFramesToWrite);
+                  }
                   if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
                     mainw->audio_frame_buffer->samples_filled += numFramesToWrite;
                     pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -862,6 +884,9 @@ static int audio_process(nframes_t nframes, void *arg) {
                 append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
               }
             }
+            if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+              sample_silence_stream(jackd->num_output_channels, numFramesToWrite);
+            }
             if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
               mainw->audio_frame_buffer->samples_filled += numFramesToWrite;
               pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -885,6 +910,9 @@ static int audio_process(nframes_t nframes, void *arg) {
             append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
           }
         }
+        if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+          sample_silence_stream(jackd->num_output_channels, numFramesToWrite);
+        }
         if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
           mainw->audio_frame_buffer->samples_filled += numFramesToWrite;
           pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -898,8 +926,9 @@ static int audio_process(nframes_t nframes, void *arg) {
     }
 
     if (!from_memory) {
-      if (!wait_cache_buffer && mainw->agen_key == 0)
+      if (!wait_cache_buffer && mainw->agen_key == 0) {
         push_cache_buffer(cache_buffer, jackd, in_bytes, nframes, shrink_factor);
+      }
       if (shrink_factor > 0.) jackd->seek_pos += xin_bytes;
     }
 
@@ -921,9 +950,12 @@ static int audio_process(nframes_t nframes, void *arg) {
         for (i = 0; i < jackd->num_output_channels; i++) {
           sample_silence_dS(out_buffer[i] + (nframes - jackFramesAvailable), jackFramesAvailable);
           if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
-            append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
+            append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], jackFramesAvailable, i);
           }
         }
+        if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+          sample_silence_stream(jackd->num_output_channels, jackFramesAvailable);
+        }
         if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
           mainw->audio_frame_buffer->samples_filled += jackFramesAvailable;
           pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -953,6 +985,9 @@ static int audio_process(nframes_t nframes, void *arg) {
         append_to_audio_bufferf(mainw->audio_frame_buffer, out_buffer[i], nframes, i);
       }
     }
+    if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+      sample_silence_stream(jackd->num_output_channels, nframes);
+    }
     if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
       mainw->audio_frame_buffer->samples_filled += nframes;
       pthread_mutex_unlock(&mainw->abuf_frame_mutex);
@@ -1022,6 +1057,9 @@ int lives_start_ready_callback(jack_transport_state_t state, jack_position_t *po
 
 static size_t audio_read_inner(jack_driver_t *jackd, float **in_buffer, int ofileno, int nframes,
                                double out_scale, boolean rev_endian, boolean out_unsigned, size_t rbytes) {
+
+  // read audio and write it to aud_rec_fd
+
   int frames_out;
 
   void *holding_buff = lives_try_malloc(rbytes);
@@ -1097,7 +1135,7 @@ static int audio_read(nframes_t nframes, void *arg) {
     // we may wish to analyse the audio for example, or push it to a video generator
 
     if (has_audio_filters(AF_TYPE_A)) {
-      uint64_t tc = jackd->audio_ticks + (uint64_t)(jackd->frames_written / (double)jackd->sample_in_rate * U_SEC);
+      uint64_t tc = jackd->audio_ticks + (uint64_t)(jackd->frames_written / (double)jackd->sample_in_rate * TICKS_PER_SECOND_DBL);
 
       if (mainw->audio_frame_buffer != NULL && prefs->audio_src == AUDIO_SRC_EXT) {
         // if we have audio triggered gens., push audio to it
@@ -1225,14 +1263,14 @@ int jack_open_device(jack_driver_t *jackd) {
 
   // TODO - use alarm
 
-  stime = lives_get_current_ticks();
+  stime = lives_get_current_ticks(0, 0);
 
   while (jackd->client == NULL && ntime < LIVES_SHORT_TIMEOUT) {
     jackd->client = jack_client_open(client_name, options, &status, server_name);
 
     lives_usleep(prefs->sleep_time);
 
-    ntime = lives_get_current_ticks() - stime;
+    ntime = lives_get_current_ticks(0, 0) - stime;
   }
 
   if (jackd->client == NULL) {
@@ -1604,8 +1642,8 @@ int jack_audio_init(void) {
     jackd->msgq = NULL;
     jackd->num_calls = 0;
     jackd->astream_fd = -1;
+    jackd->abs_maxvol_heard = 0.;
     jackd->jackd_died = FALSE;
-    gettimeofday(&jackd->last_reconnect_attempt, 0);
     jackd->num_output_channels = 2;
     jackd->play_when_stopped = FALSE;
     jackd->mute = FALSE;
@@ -1637,8 +1675,8 @@ int jack_audio_read_init(void) {
     jackd->msgq = NULL;
     jackd->num_calls = 0;
     jackd->astream_fd = -1;
+    jackd->abs_maxvol_heard = 0.;
     jackd->jackd_died = FALSE;
-    gettimeofday(&jackd->last_reconnect_attempt, 0);
     jackd->num_input_channels = 2;
     jackd->play_when_stopped = FALSE;
     jackd->mute = FALSE;
@@ -1680,8 +1718,9 @@ uint64_t lives_jack_get_time(jack_driver_t *jackd, boolean absolute) {
   frames_written = jackd->frames_written;
   if (frames_written < 0.) frames_written = 0.;
 
-  if (jackd->is_output) xtime = jackd->audio_ticks * absolute + (uint64_t)(frames_written / (double)jackd->sample_out_rate * U_SEC);
-  else xtime = jackd->audio_ticks * absolute + (uint64_t)(frames_written / (double)jackd->sample_in_rate * U_SEC);
+  if (jackd->is_output) xtime = jackd->audio_ticks * absolute + (uint64_t)(frames_written / (double)jackd->sample_out_rate *
+                                  TICKS_PER_SECOND_DBL);
+  else xtime = jackd->audio_ticks * absolute + (uint64_t)(frames_written / (double)jackd->sample_in_rate * TICKS_PER_SECOND_DBL);
   return xtime;
 }
 
@@ -1808,8 +1847,7 @@ void jack_aud_pb_ready(int fileno) {
     if (sfile->achans > 0 && (!mainw->preview || (mainw->preview && mainw->is_processing)) &&
         (sfile->laudio_time > 0. || sfile->opening ||
          (mainw->multitrack != NULL && mainw->multitrack->is_rendering &&
-          lives_file_test((tmpfilename = lives_build_filename(prefs->workdir, sfile->handle, "audio", NULL)),
-                          LIVES_FILE_TEST_EXISTS)))) {
+          lives_file_test((tmpfilename = lives_get_audio_file_name(fileno)), LIVES_FILE_TEST_EXISTS)))) {
       boolean timeout;
       int alarm_handle;
 
