@@ -126,7 +126,7 @@ LiVESFilterReturn filter_func(LiVESXXEvent *xevent, LiVESXEvent *event, livespoi
   key = xev->xkey.state;
   modifiers = xev->xkey.state;
 
-  modifiers = (lives_accelerator_get_default_mod_mask() & modifiers) | NEEDS_TRANSLATION;
+  modifiers = (LIVES_DEFAULT_MOD_MASK & modifiers) | NEEDS_TRANSLATION;
 
   // key down
   if (xev->type == LIVES_XEVENT_TYPE_KEYPRESS) return pl_key_function(TRUE, key, modifiers) ? LIVES_FILTER_REMOVE : LIVES_FILTER_CONTINUE;
@@ -198,7 +198,7 @@ void handle_cached_keys(void) {
 
   static int last_kb_time = 0, current_kb_time;
 
-  current_kb_time = mainw->currticks * (1000 / U_SEC_RATIO);
+  current_kb_time = mainw->currticks * (1000 / USEC_TO_TICKS);
 
   if (cached_key && current_kb_time - last_kb_time > KEY_RPT_INTERVAL * 10) {
     last_kb_time = current_kb_time;
@@ -459,7 +459,7 @@ boolean fade_callback(LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval,
 
 
 boolean showfct_callback(LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, livespointer user_data) {
-  lives_check_menu_item_set_active(LIVES_CHECK_MENU_ITEM(mainw->showfct), !prefs->show_framecount);
+  lives_check_menu_item_set_active(LIVES_CHECK_MENU_ITEM(mainw->showfct), prefs->hide_framebar);
   return TRUE;
 }
 
