@@ -718,10 +718,8 @@ static boolean call_set_current_time(livespointer data) {
         mt_tl_move(mainw->multitrack, idata->stime);
       }
     } else {
-      if (mainw->current_file > 0 && idata->stime >= 0. && idata->stime <= cfile->total_time) {
-        cfile->pointer_time = idata->stime;
-        lives_ruler_set_value(LIVES_RULER(mainw->hruler), cfile->pointer_time);
-        lives_widget_queue_draw(mainw->hruler);
+      if (mainw->current_file > 0 && idata->stime >= 0. && idata->stime <= CLIP_TOTAL_TIME(mainw->current_file)) {
+        cfile->pointer_time = lives_ce_update_timeline(0, idata->stime);
         get_play_times();
       }
     }
