@@ -55,6 +55,10 @@ POSSIBILITY OF SUCH DAMAGES.
 #undef HAVE_UNICAP
 #endif
 
+#define ENABLE_OSC2
+
+#define BACKEND_NAME "smogrify"
+
 #ifndef GUI_QT
 #define GUI_GTK
 #define PAINTER_CAIRO
@@ -199,6 +203,7 @@ typedef int lives_pgid_t;
 #define DESKTOP_ICON_DIR "/share/icons/hicolor/48x48/apps"
 #define DATA_DIR "/share/lives/"
 #define LIVES_CONFIG_DIR ".lives-dir/"
+#define LIVES_DEVICEMAP_DIR "devicemaps"
 #define LIVES_WORK_NAME "livesprojects"
 
 #else // IS_MINGW
@@ -1203,6 +1208,7 @@ int lives_rmdir_with_parents(const char *dir);
 int lives_rm(const char *file);
 int lives_rmglob(const char *files);
 int lives_cp(const char *from, const char *to);
+int lives_cp_recursive(const char *from, const char *to);
 int lives_cp_keep_perms(const char *from, const char *to);
 int lives_mv(const char *from, const char *to);
 int lives_touch(const char *tfile);
@@ -1250,7 +1256,6 @@ lives_image_type_t lives_image_type_to_image_type(const char *lives_img_type);
 
 void set_menu_text(LiVESWidget *menu, const char *text, boolean use_mnemonic);
 void get_menu_text(LiVESWidget *menu, char *text);
-void get_menu_text_long(LiVESWidget *menuitem, char *text);
 void reset_clipmenu(void);
 
 double lives_ce_update_timeline(int frame, double x);  ///< pointer position in timeline
