@@ -1,6 +1,6 @@
 // mainwindow.h
 // LiVES (lives-exe)
-// (c) G. Finch <salsaman+lives@gmail.com> 2003 - 2017
+// (c) G. Finch <salsaman+lives@gmail.com> 2003 - 2018
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -112,9 +112,6 @@
 
 #define MAIN_SPIN_SPACER ((int)52.*widget_opts.scale) ///< pixel spacing for start/end spins for clip and multitrack editors
 
-/// blank label to show so our message dialogs are not too small
-#define PROCW_STRETCHER "                                                                                                                            "
-
 #define ENC_DETAILS_WIN_H ((int)(640.*widget_opts.scale)) ///< horizontal size in pixels of the encoder output window
 #define ENC_DETAILS_WIN_V ((int)(240.*widget_opts.scale)) ///< vertical size in pixels of the encoder output window
 
@@ -172,11 +169,11 @@ typedef enum {
   LIVES_TIME_SOURCE_EXTERNAL
 } lives_time_source_t;
 
+/// toy types
 typedef enum {
   LIVES_TOY_NONE = 0,
   LIVES_TOY_MAD_FRAMES,
-  LIVES_TOY_TV,
-  LIVES_TOY_AUTOLIVES
+  LIVES_TOY_TV
 } lives_toy_t;
 
 typedef enum {
@@ -581,7 +578,7 @@ typedef struct {
   int pre_src_audio_file; ///< audio file we were playing before any ext input started
 
   lives_toy_t toy_type;
-  lives_pgid_t toy_alives_pgid; // 0, or thread for autolives toy
+  lives_pgid_t alives_pgid; // 0, or procid for autolives
   boolean autolives_reset_fx;
 
   boolean toy_go_wild;
@@ -650,7 +647,7 @@ typedef struct {
   uint64_t stream_ticks;  ///< ticks since first frame sent to playback plugin
   uint64_t last_display_ticks; /// currticks when last display was shown (used for fixed fps)
 
-  boolean size_warn; ///< warn the user that incorrectly sized frames were found
+  int size_warn; ///< warn the user that incorrectly sized frames were found
 
   /// set to TRUE during frame load/display operation. If TRUE we should not switch clips,
   /// close the current clip, or call load_frame_image()
@@ -738,7 +735,6 @@ typedef struct {
   ulong toy_func_none;
   ulong toy_func_random_frames;
   ulong toy_func_lives_tv;
-  ulong toy_func_autolives;
   ulong hnd_id;
   ulong loop_cont_func;
   ulong mute_audio_func;
@@ -890,7 +886,7 @@ typedef struct {
   LiVESWidget *toy_none;
   LiVESWidget *toy_random_frames;
   LiVESWidget *toy_tv;
-  LiVESWidget *toy_autolives;
+  LiVESWidget *autolives;
   LiVESWidget *show_file_info;
   LiVESWidget *show_file_comments;
   LiVESWidget *show_clipboard_info;
@@ -1228,8 +1224,11 @@ typedef struct {
 #ifdef ALSA_MIDI
   snd_seq_t *seq_handle;
   int alsa_midi_port;
+  int alsa_midi_dummy;
 #endif
 
+  boolean midi_channel_lock;
+
   weed_plant_t *rte_textparm; ///< send keyboard input to this paramter (usually NULL)
 
   int write_abuf; ///< audio buffer number to write to (for multitrack)
@@ -1373,6 +1372,7 @@ typedef struct {
   uint64_t aud_data_written;
 
   char *dp_cache;
+
   ////////////////////
 } mainwindow;
 
