@@ -1,6 +1,6 @@
 // plugins.h
 // LiVES
-// (c) G. Finch 2003-2016 <salsaman@gmail.com>
+// (c) G. Finch 2003-2017 <salsaman+lives@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -16,7 +16,6 @@
 #include <fcntl.h>
 #include <stdlib.h>
 
-
 // generic plugins
 
 LiVESList *get_plugin_list(const char *plugin_type, boolean allow_nonex, const char *plugdir, const char *filter_ext);
@@ -35,7 +34,6 @@ LiVESList *get_plugin_list(const char *plugin_type, boolean allow_nonex, const c
 #define PLUGIN_EFFECTS_WEED "weed"
 #define PLUGIN_WEED_FX_BUILTIN "effects/realtime/weed"
 
-
 LiVESList *plugin_request(const char *plugin_type, const char *plugin_name, const char *request);
 LiVESList *plugin_request_with_blanks(const char *plugin_type, const char *plugin_name, const char *request);
 LiVESList *plugin_request_by_line(const char *plugin_type, const char *plugin_name, const char *request);
@@ -50,7 +48,6 @@ typedef weed_plant_t *(*weed_bootstrap_f)(weed_default_getter_f *value, int num_
 /// video playback plugins
 typedef boolean(*plugin_keyfunc)(boolean down, uint16_t unicode, uint16_t keymod);
 
-
 typedef struct {
   // playback
   char name[64];
@@ -75,7 +72,7 @@ typedef struct {
   const char *(*get_fps_list)(int palette);
   boolean(*set_fps)(double fps);
 
-  const char *(*get_init_rfx)(void);
+  const char *(*get_init_rfx)(int intention);
 
   ///< optional (but should return a weed plantptr array of paramtmpl and chantmpl, NULL terminated)
   const weed_plant_t **(*get_play_params)(weed_bootstrap_f f);
@@ -84,16 +81,20 @@ typedef struct {
   int *(*get_yuv_palette_sampling)(int palette);
   int *(*get_yuv_palette_clamping)(int palette);
   int *(*get_yuv_palette_subspace)(int palette);
-  int (*set_yuv_palette_sampling)(int palette);
-  int (*set_yuv_palette_clamping)(int palette);
-  int (*set_yuv_palette_subspace)(int palette);
+  int (*set_yuv_palette_sampling)(int sampling_type);
+  int (*set_yuv_palette_clamping)(int clamping_type);
+  int (*set_yuv_palette_subspace)(int subspace_type);
 
-  // audio streaming
+  // audio streaming (deprecated, use init_audio(), render_audio_frame())
   int *(*get_audio_fmts)(void);
 
-  uint32_t audio_codec;
+  uint32_t audio_codec; //(deprecated, use init_audio(), render_audio_frame())
   // must match with the "acodec" LiVESList in interface.c
-  // and bitmaps in the encder plugins, with this one addition:
+  // and bitmaps in the encder plugins
+
+  // optional audio packeting
+  boolean(*init_audio)(int in_sample_rate, int in_nchans, int argc, char **argv);
+  boolean(*render_audio_frame_float)(float **audio, int nsamps);
 
   uint64_t capabilities;
 
@@ -122,9 +123,10 @@ typedef struct {
   int num_alpha_chans;
 } _vid_playback_plugin;
 
+#define DEFAULT_VPP "openGL"
 
-#define DEF_VPP_HSIZE 320.
-#define DEF_VPP_VSIZE 240.
+#define MAX_VPP_HSIZE 1024.
+#define MAX_VPP_VSIZE 576.
 
 _vid_playback_plugin *open_vid_playback_plugin(const char *name, boolean in_use);
 void vid_playback_plugin_exit(void);
@@ -133,7 +135,6 @@ int64_t get_best_audio(_vid_playback_plugin *);
 void save_vpp_defaults(_vid_playback_plugin *, char *file);
 void load_vpp_defaults(_vid_playback_plugin *, char *file);
 
-
 const weed_plant_t *pp_get_param(weed_plant_t **pparams, int idx);
 const weed_plant_t *pp_get_chan(weed_plant_t **pparams, int idx);
 
@@ -147,7 +148,6 @@ const weed_plant_t *pp_get_chan(weed_plant_t **pparams, int idx);
 #define HI_H_MKV_FORMAT "hi_h-mkv"
 #define HI_H_AVI_FORMAT "hi_h-avi"
 
-
 void do_plugin_encoder_error(const char *plugin_name_or_null);
 
 LiVESList *filter_encoders_by_img_ext(LiVESList *encoders, const char *img_ext);
@@ -168,7 +168,6 @@ typedef struct {
 #define AUDIO_CODEC_RAW 7       // reserved
 #define AUDIO_CODEC_WMA2 8
 
-
 #define AUDIO_CODEC_MAX 31
   //
 #define AUDIO_CODEC_NONE 32
@@ -176,7 +175,6 @@ typedef struct {
 
   uint32_t capabilities;
 
-
 #define HAS_RFX (1<<0)
 
 #define CAN_ENCODE_PNG (1<<2)
@@ -192,11 +190,9 @@ typedef struct {
 }
 _encoder;
 
-
 // defined in plugins.c for the whole app
 extern const char *anames[AUDIO_CODEC_MAX];
 
-
 // decoder plugins
 
 // seek_flags is a bitmap
@@ -208,7 +204,6 @@ extern const char *anames[AUDIO_CODEC_MAX];
 #define LIVES_SEEK_NEEDS_CALCULATION (1<<1)
 #define LIVES_SEEK_QUALITY_LOSS (1<<2)
 
-
 // must be exactly the same as in decplugin.h
 
 typedef struct {
@@ -273,12 +268,9 @@ typedef struct {
 
   int sync_hint;
 
-
   void *priv; ///< private data for demuxer/decoder - host should not touch this
 } lives_clip_data_t;
 
-
-
 typedef struct {
   // playback
   char *name; ///< plugin name
@@ -313,18 +305,11 @@ typedef struct {
   void (*module_unload)(void);
 } lives_decoder_sys_t;
 
-
-
-
 typedef struct {
   const lives_decoder_sys_t *decoder;
   lives_clip_data_t *cdata;
 } lives_decoder_t;
 
-
-
-
-
 const lives_clip_data_t *get_decoder_cdata(int fileno, LiVESList *disabled, const lives_clip_data_t *fake_cdata);
 void close_decoder_plugin(lives_decoder_t *);
 lives_decoder_sys_t *open_decoder_plugin(const char *plname);
@@ -335,10 +320,8 @@ boolean decplugin_supports_palette(const lives_decoder_t *dplug, int palette);
 
 lives_decoder_t *clone_decoder(int fileno);
 
-
 // RFX plugins
 
-
 /// external rendered fx plugins (RFX plugins)
 #define PLUGIN_RENDERED_EFFECTS_BUILTIN "effects/rendered/"
 
@@ -356,13 +339,11 @@ lives_decoder_t *clone_decoder(int fileno);
 /// scraps are passed between programs to generate param windows
 #define PLUGIN_RFX_SCRAP ""
 
-
 /// max number of display widgets per parameter (currently 5 for RGBA spinbuttons + colorbutton)
 #define MAX_PARAM_WIDGETS 5
 
 /// length of max string (not including terminating NULL) for LiVES-perl
-#define RFX_MAXSTRINGLEN 1024
-
+#define RFX_MAXSTRINGLEN (PATH_MAX - 1)
 
 typedef enum {
   LIVES_PARAM_UNKNOWN = 0,
@@ -376,13 +357,11 @@ typedef enum {
   LIVES_PARAM_UNDISPLAYABLE = 65536
 } lives_param_type_t;
 
-
 typedef enum {
   LIVES_RFX_SOURCE_RFX = 0,
   LIVES_RFX_SOURCE_WEED
 } lives_rfx_source_t;
 
-
 typedef enum {
   LIVES_PARAM_SPECIAL_TYPE_NONE = 0, // normal parameter type
 
@@ -401,7 +380,6 @@ typedef enum {
   LIVES_PARAM_SPECIAL_TYPE_ASPECT_RATIO
 } lives_param_special_t;
 
-
 typedef struct {
   // weed style part
   char *name;
@@ -464,7 +442,6 @@ typedef struct {
   int special_type_index; // index within special_type (e.g for DEMASK, 0==left, 1==top, 2==width, 3==height)
 } lives_param_t;
 
-
 typedef enum {
   RFX_STATUS_BUILTIN = 0, ///< factory presets
   RFX_STATUS_CUSTOM = 1, ///< custom effects in the custom menu
@@ -478,9 +455,6 @@ typedef enum {
   RFX_STATUS_RENAME = 129 ///< indicates a copy operation to test
 } lives_rfx_status_t;
 
-
-
-
 typedef struct {
   char *name;  ///< the name of the executable (so we can run it !)
   char *menu_text; ///< for Weed, this is the filter_class "name"
@@ -489,13 +463,11 @@ typedef struct {
   int num_in_channels;
   lives_rfx_status_t status;
 
-
   uint32_t props;
 #define RFX_PROPS_SLOW        0x0001  ///< hint to GUI
 #define RFX_PROPS_MAY_RESIZE  0x0002 ///< is a tool
 #define RFX_PROPS_BATCHG      0x0004 ///< is a batch generator
 
-
 #define RFX_PROPS_RESERVED1   0x1000
 #define RFX_PROPS_RESERVED2   0x2000
 #define RFX_PROPS_RESERVED3   0x4000
@@ -506,7 +478,6 @@ typedef struct {
   uint32_t flags; /// internal use
 #define RFX_FLAGS_NO_SLIDERS 0x0001
 
-
   lives_param_t *params;
   lives_rfx_source_t source_type;
   void *source;  ///< points to the source (e.g. a weed_plant_t)
@@ -515,7 +486,6 @@ typedef struct {
   boolean is_template;
 } lives_rfx_t;
 
-
 boolean check_rfx_for_lives(lives_rfx_t *);
 
 void do_rfx_cleanup(lives_rfx_t *);
@@ -528,14 +498,19 @@ int find_rfx_plugin_by_name(const char *name, short status);
 
 void rfx_copy(lives_rfx_t *src, lives_rfx_t *dest, boolean full);
 
-void rfx_params_free(lives_rfx_t *rfx);
+void rfx_params_free(lives_rfx_t *);
 
-void rfx_free(lives_rfx_t *rfx);
+void rfx_free(lives_rfx_t *);
 
 void rfx_free_all(void);
 
 void param_copy(lives_param_t *src, lives_param_t *dest, boolean full);
 
+lives_param_t *find_rfx_param_by_name(lives_rfx_t *, const char *name);
+
+boolean set_rfx_param_by_name_string(lives_rfx_t *, const char *name, const char *value, boolean update_visual);
+
+boolean get_rfx_param_by_name_string(lives_rfx_t *rfx, const char *name, char **return_value);
 
 typedef struct {
   LiVESList *list; ///< list of filter_idx from which user can delegate
@@ -551,10 +526,6 @@ typedef struct {
 
 #define MAX_FX_CANDIDATE_TYPES 3
 
-
-
-
-
 boolean get_bool_param(void *value);
 int get_int_param(void *value);
 double get_double_param(void *value);
@@ -589,6 +560,7 @@ typedef struct {
   LiVESWidget *fps_entry;
   LiVESWidget *pal_entry;
   lives_rfx_t *rfx;
+  boolean keep_rfx;
 } _vppaw;
 
 _vppaw *on_vpp_advanced_clicked(LiVESButton *, livespointer);
@@ -597,8 +569,6 @@ void on_decplug_advanced_clicked(LiVESButton *button, livespointer user_data);
 LiVESList *get_external_window_hints(lives_rfx_t *rfx);
 boolean check_encoder_restrictions(boolean get_extension, boolean user_audio, boolean save_all);
 
-
-
 /// for realtime effects, see effects-weed.h
 
 #endif
