@@ -267,6 +267,7 @@ typedef struct {
 #define OMC_DEV_MIDI (1<<0)
 #define OMC_DEV_JS (1<<1)
 #define OMC_DEV_FORCE_RAW_MIDI (1<<2)
+#define OMC_DEV_MIDI_DUMMY (1<<3)
   uint32_t omc_dev_opts;
 
   char omc_js_fname[PATH_MAX];  ///< utf8
@@ -279,9 +280,13 @@ typedef struct {
   boolean safe_symlinks;
 
 #ifdef ALSA_MIDI
+
   boolean use_alsa_midi;
+  boolean alsa_midi_dummy;
 #endif
 
+  int midi_rcv_channel;
+
   int startup_interface;
 
 #define STARTUP_CE 0
@@ -586,7 +591,9 @@ typedef struct {
   LiVESWidget *omc_midi_entry;
   LiVESWidget *spinbutton_midicr;
   LiVESWidget *spinbutton_midirpt;
+  LiVESWidget *midichan_combo;
   LiVESWidget *alsa_midi;
+  LiVESWidget *alsa_midi_dummy;
   LiVESWidget *button_midid;
   LiVESWidget *rb_startup_ce;
   LiVESWidget *rb_startup_mt;
@@ -614,6 +621,7 @@ typedef struct {
   boolean ign_clipset;
   boolean ign_osc;
   boolean ign_aplayer;
+  boolean ign_asource;
   boolean ign_stmode;
   boolean ign_vppdefs;
 } _ign_opts;
@@ -780,6 +788,8 @@ void apply_button_set_enabled(LiVESWidget *widget, livespointer func_data);
 #define PREF_MIDI_CHECK_RATE "midi_check_rate"
 #define PREF_MIDI_RPT "midi_rpt"
 
+#define PREF_MIDI_RCV_CHANNEL "midi_rcv_channel"
+
 #define PREF_ENCODER_ACODEC "encoder_acodec"
 
 #define PREF_AUDIO_OPTS "audio_opts"
