@@ -1,6 +1,6 @@
 // resample.h
 // LiVES
-// (c) G. Finch 2004 - 2012 <salsaman@gmail.com>
+// (c) G. Finch 2004 - 2016 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -48,7 +48,8 @@ weed_timecode_t q_gint64_floor(weed_timecode_t in, double fps);
 weed_timecode_t q_dbl(double in, double fps);
 
 
-weed_plant_t *quantise_events(weed_plant_t *in_list, double new_fps, boolean allow_gap);  ///< quantise frame events for a single clip
+weed_plant_t *quantise_events(weed_plant_t *in_list, double new_fps,
+                              boolean allow_gap) WARN_UNUSED;  ///< quantise frame events for a single clip
 
 ///////////////////////////////////////////////////////
 int count_resampled_frames(int in_frames, double orig_fps, double resampled_fps);
@@ -63,7 +64,7 @@ void create_new_pb_speed(short type);
 ///
 /// type 1 : show current and new,
 /// type 2 : show new
-_resaudw *create_resaudw(short type, render_details *rdet, LiVESWidget *top_vbox);
+_resaudw *create_resaudw(short type, render_details *, LiVESWidget *top_vbox);
 
 void on_change_speed_activate(LiVESMenuItem *, livespointer);
 void on_change_speed_ok_clicked(LiVESButton *, livespointer);
