@@ -1,9 +1,8 @@
 // LiVES - videodev input
-// (c) G. Finch 2010 - 2016 <salsaman@gmail.com>
+// (c) G. Finch 2010 - 2017 <salsaman+lives@gmail.com>
 // released under the GNU GPL 3 or later
 // see file COPYING or www.gnu.org for details
 
-
 #include "main.h"
 
 #ifdef HAVE_UNICAP
@@ -32,27 +31,15 @@
 
 #include <unicap/unicap.h>
 
-////////////////////////////////////////////////////
-
-
 
 static boolean lives_wait_user_buffer(lives_vdev_t *ldev, unicap_data_buffer_t **buff, double timeout) {
   // wait for USER type buffer
-#ifndef USE_MONOTONIC_TIME
-  struct timeval otv;
-#endif
   int64_t stime, dtime, timer;
   unicap_status_t status;
   int ncount;
 
-  timer = timeout * 1000000.;
-
-#ifdef USE_MONOTONIC_TIME
-  stime = lives_get_monotonic_time() * U_SEC_RATIO;
-#else
-  gettimeofday(&otv, NULL);
-  stime = otv.tv_sec * 1000000 + otv.tv_usec;
-#endif
+  timer = timeout * TICKS_PER_SECOND;
+  stime = lives_get_current_ticks(0, 0);
 
   while (1) {
     status = unicap_poll_buffer(ldev->handle, &ncount);
@@ -66,12 +53,7 @@ static boolean lives_wait_user_buffer(lives_vdev_t *ldev, unicap_data_buffer_t *
       return TRUE;
     }
 
-#ifdef USE_MONOTONIC_TIME
-    dtime = lives_get_monotonic_time() * U_SEC_RATIO;
-#else
-    gettimeofday(&otv, NULL);
-    dtime = otv.tv_sec * 1000000 + otv.tv_usec;
-#endif
+    dtime = lives_get_current_ticks(0, 0);
     if (dtime - stime > timer) return FALSE;
 
     lives_usleep(prefs->sleep_time);
@@ -82,31 +64,16 @@ static boolean lives_wait_user_buffer(lives_vdev_t *ldev, unicap_data_buffer_t *
 }
 
 
-
 static boolean lives_wait_system_buffer(lives_vdev_t *ldev, double timeout) {
   // wait for SYSTEM type buffer
-#ifndef USE_MONOTONIC_TIME
-  struct timeval otv;
-#endif
   int64_t stime, dtime, timer;
 
-  timer = timeout * 1000000.;
+  timer = timeout * TICKS_PER_SECOND;
+  stime = lives_get_current_ticks(0, 0);
 
-#ifdef USE_MONOTONIC_TIME
-  stime = lives_get_monotonic_time() * U_SEC_RATIO;
-#else
-  gettimeofday(&otv, NULL);
-  stime = otv.tv_sec * 1000000 + otv.tv_usec;
-#endif
   while (ldev->buffer_ready == 0) {
-#ifdef USE_MONOTONIC_TIME
-    dtime = lives_get_monotonic_time() * U_SEC_RATIO;
-#else
-    gettimeofday(&otv, NULL);
-    dtime = otv.tv_sec * 1000000 + otv.tv_usec;
-#endif
+    dtime = lives_get_current_ticks(0, 0);
     if (dtime - stime > timer) return FALSE;
-
     lives_usleep(prefs->sleep_time);
     lives_widget_context_update();
   }
@@ -115,8 +82,6 @@ static boolean lives_wait_system_buffer(lives_vdev_t *ldev, double timeout) {
 }
 
 
-
-
 static void new_frame_cb(unicap_event_t event, unicap_handle_t handle,
                          unicap_data_buffer_t *buffer, void *usr_data) {
   lives_vdev_t *ldev = (lives_vdev_t *)usr_data;
@@ -136,8 +101,6 @@ static void new_frame_cb(unicap_event_t event, unicap_handle_t handle,
 }
 
 
-
-
 boolean weed_layer_set_from_lvdev(weed_plant_t *layer, lives_clip_t *sfile, double timeoutsecs) {
   lives_vdev_t *ldev = (lives_vdev_t *)sfile->ext_src;
   unicap_data_buffer_t *returned_buffer = NULL;
@@ -345,9 +308,6 @@ static unicap_format_t *lvdev_get_best_format(const unicap_format_t *formats,
 }
 
 
-
-
-
 /// get devnumber from user and open it to a new clip
 
 static boolean open_vdev_inner(unicap_device_t *device) {
@@ -407,7 +367,6 @@ static boolean open_vdev_inner(unicap_device_t *device) {
     return FALSE;
   }
 
-
   if (format->buffer_size != format->size.width * format->size.height * weed_palette_get_bits_per_macropixel(ldev->current_palette) /
       weed_palette_get_pixels_per_macropixel(ldev->current_palette) / 8) {
     int wwidth = format->size.width, awidth;
@@ -468,7 +427,6 @@ void lives_vdev_free(lives_vdev_t *ldev) {
 }
 
 
-
 boolean on_open_vdev_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   unicap_device_t devices[MAX_DEVICES];
 
@@ -542,7 +500,6 @@ boolean on_open_vdev_activate(LiVESMenuItem *menuitem, livespointer user_data) {
     }
   }
 
-
   for (i = dev_count - 1; i >= 0; i--) {
     if (!unicap_is_stream_locked(&devices[i])) {
       if (mainw->fx1_val == 0) {
@@ -553,8 +510,8 @@ boolean on_open_vdev_activate(LiVESMenuItem *menuitem, livespointer user_data) {
     mainw->fx1_val--;
   }
 
-  if (devices[devno].device != NULL) fname = lives_strdup_printf("%s", devices[devno].device);
-  else fname = lives_strdup_printf("%s", devices[devno].identifier);
+  if (strlen(devices[devno].device)) fname = lives_strdup(devices[devno].device);
+  else fname = lives_strdup(devices[devno].identifier);
 
   if (!get_new_handle(new_file, fname)) {
     lives_free(fname);
@@ -591,7 +548,5 @@ boolean on_open_vdev_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   return TRUE;
 }
 
-
-
 #endif
 
