@@ -13,9 +13,12 @@
 
 #define GTK_RADIO_MENU_BUG // a bug where gtk_radio_menu_item_set_active() does not update visually
 #define GTK_SUBMENU_SENS_BUG // a bug where setting a menuitem insensitive fails if it has a submenu
-#define GTK_TEXT_VIEW_CSS_BUG // a bug where named textviews cannot be set by CSS
 #define GTK_TEXT_VIEW_DRAW_BUG // a bug where textview crashes if too much text in it
 
+#if !GTK_CHECK_VERSION(3, 18, 9) // fixed version 
+#define GTK_TEXT_VIEW_CSS_BUG // a bug where named textviews cannot be set by CSS
+#endif
+
 #ifndef IS_MINGW
 typedef gboolean                          boolean;
 #endif
@@ -148,6 +151,9 @@ typedef GLogLevelFlags LiVESLogLevelFlags;
 #define LIVES_TABLE_IS_GRID 1
 #endif
 
+#define LIVES_ACCEL_PATH_QUIT "<LiVES>/quit"
+#define LIVES_ACCEL_PATH_SAVE "<LiVES>/save"
+
 #define return_true gtk_true
 
 typedef void (*LiVESGuiCallback)(void);
@@ -214,6 +220,7 @@ typedef gint(*LiVESCompareFunc)(gconstpointer a, gconstpointer b);
 #define lives_slist_append(list, data) g_slist_append(list, data)
 
 #define lives_build_filename(...) g_build_filename(__VA_ARGS__)
+#define lives_build_path(...) g_build_path(LIVES_DIR_SEP, __VA_ARGS__)
 #define lives_filename_to_utf8(a, b, c, d, e) g_filename_to_utf8(a, b, c, d, e)
 #define lives_filename_from_utf8(a, b, c, d, e) g_filename_from_utf8(a, b, c, d, e)
 
@@ -299,21 +306,37 @@ typedef GdkDeviceManager                  LiVESXDeviceManager;
 #endif
 
 #if GTK_CHECK_VERSION(3, 0, 0)
+#if GTK_CHECK_VERSION(4, 0, 0)
+// gtk+ 4
+#define EXPOSE_FN_DECL(fn, widget) boolean fn(LiVESWidget *widget, lives_painter_t *cairo, int width, int height, livespointer user_data) { \
+    LiVESXEventExpose *event = NULL; \
+    (void)event; // avoid compiler warnings
+#define EXPOSE_FN_EVENT
+#define EXPOSE_FN_PROTOTYPE(fn) boolean fn(LiVESWidget *, lives_painter_t *, int, int, livespointer);
+#else
+// gtk+ 3
 #define EXPOSE_FN_DECL(fn, widget) boolean fn(LiVESWidget *widget, lives_painter_t *cairo, livespointer user_data) { \
     LiVESXEventExpose *event = NULL; \
-    event = event; // avoid compiler warnings
+    (void)event;
 #define EXPOSE_FN_EVENT
 #define EXPOSE_FN_PROTOTYPE(fn) boolean fn(LiVESWidget *, lives_painter_t *, livespointer);
+#endif
 #else
+// gtk+ 2
 #define EXPOSE_FN_DECL(fn, widget) boolean fn(LiVESWidget *widget, LiVESXEventExpose *event, livespointer user_data) { \
-    lives_painter_t *cairo = NULL; \
-    cairo = cairo; // avoid compiler warnings
+    lives_painter_t *cairo = NULL;
 #define EXPOSE_FN_PAINTER
 #define EXPOSE_FN_PROTOTYPE(fn) boolean fn(LiVESWidget *, LiVESXEventExpose *, livespointer);
 #endif
 
+#define EXPOSE_FN_END }
+
 #if GTK_CHECK_VERSION(3, 0, 0)
+#if GTK_CHECK_VERSION(4, 0, 0)
+#define LIVES_WIDGET_EXPOSE_EVENT "snapshot"
+#else
 #define LIVES_WIDGET_EXPOSE_EVENT "draw"
+#endif
 #define LIVES_GUI_OBJECT(a)                     a
 #else
 #define LIVES_GUI_OBJECT(a)                     GTK_OBJECT(a)
@@ -416,6 +439,7 @@ typedef GtkMenu                           LiVESMenu;
 typedef GtkMenuShell                      LiVESMenuShell;
 typedef GtkMenuItem                       LiVESMenuItem;
 typedef GtkMenuToolButton                 LiVESMenuToolButton;
+typedef GtkToggleToolButton               LiVESToggleToolButton;
 typedef GtkCheckMenuItem                  LiVESCheckMenuItem;
 typedef GtkImageMenuItem                  LiVESImageMenuItem;
 typedef GtkRadioMenuItem                  LiVESRadioMenuItem;
@@ -757,6 +781,7 @@ typedef GdkInterpType                     LiVESInterpType;
 #endif
 
 #define LIVES_TOGGLE_BUTTON(widget) GTK_TOGGLE_BUTTON(widget)
+#define LIVES_TOGGLE_TOOL_BUTTON(widget) GTK_TOGGLE_TOOL_BUTTON(widget)
 #define LIVES_TEXT_VIEW(widget) GTK_TEXT_VIEW(widget)
 #define LIVES_TEXT_BUFFER(widget) GTK_TEXT_BUFFER(widget)
 
@@ -832,6 +857,7 @@ typedef GdkInterpType                     LiVESInterpType;
 #define LIVES_IS_BUTTON(widget) GTK_IS_BUTTON(widget)
 #define LIVES_IS_SPIN_BUTTON(widget) GTK_IS_SPIN_BUTTON(widget)
 #define LIVES_IS_TOGGLE_BUTTON(widget) GTK_IS_TOGGLE_BUTTON(widget)
+#define LIVES_IS_TOGGLE_TOOL_BUTTON(widget) GTK_IS_TOGGLE_TOOL_BUTTON(widget)
 #define LIVES_IS_IMAGE(widget) GTK_IS_IMAGE(widget)
 #define LIVES_IS_ENTRY(widget) GTK_IS_ENTRY(widget)
 #define LIVES_IS_RANGE(widget) GTK_IS_RANGE(widget)
@@ -869,6 +895,7 @@ typedef GdkInterpType                     LiVESInterpType;
 #define LIVES_STOCK_GO_FORWARD "go-next"
 #define LIVES_STOCK_GO_UP "go-up"
 #define LIVES_STOCK_GO_DOWN "go-down"
+#define LIVES_STOCK_SELECT_ALL "edit-select-all"
 #define LIVES_STOCK_REFRESH "view-refresh"
 #define LIVES_STOCK_MEDIA_PLAY "media-playback-start"
 #define LIVES_STOCK_MEDIA_STOP "media-playback-stop"
@@ -880,6 +907,7 @@ typedef GdkInterpType                     LiVESInterpType;
 #define LIVES_STOCK_DIALOG_INFO "dialog-information"
 #define LIVES_STOCK_MISSING_IMAGE "image-missing"
 
+// these are set up in widget_helper_init()
 char LIVES_STOCK_LABEL_CANCEL[32];
 char LIVES_STOCK_LABEL_OK[32];
 char LIVES_STOCK_LABEL_YES[32];
@@ -893,6 +921,7 @@ char LIVES_STOCK_LABEL_CLOSE[32];
 char LIVES_STOCK_LABEL_REVERT[32];
 char LIVES_STOCK_LABEL_REFRESH[32];
 char LIVES_STOCK_LABEL_DELETE[32];
+char LIVES_STOCK_LABEL_SELECT_ALL[32];
 char LIVES_STOCK_LABEL_GO_FORWARD[32];
 
 char LIVES_STOCK_LABEL_MEDIA_FORWARD[32];
@@ -924,6 +953,7 @@ char LIVES_STOCK_LABEL_MEDIA_RECORD[32];
 #define LIVES_STOCK_GO_BACK GTK_STOCK_GO_BACK
 #define LIVES_STOCK_GO_FORWARD GTK_STOCK_GO_FORWARD
 #define LIVES_STOCK_REFRESH GTK_STOCK_REFRESH
+#define LIVES_STOCK_SELECT_ALL GTK_STOCK_SELECT_ALL
 #define LIVES_STOCK_PREFERENCES GTK_STOCK_PREFERENCES
 #define LIVES_STOCK_DIALOG_INFO GTK_STOCK_DIALOG_INFO
 #define LIVES_STOCK_MISSING_IMAGE GTK_STOCK_MISSING_IMAGE
@@ -984,11 +1014,19 @@ char LIVES_STOCK_LABEL_MEDIA_RECORD[32];
 
 #endif
 
+#define LIVES_DEFAULT_MOD_MASK (gtk_accelerator_get_default_mod_mask ())
+
 #define LIVES_CONTROL_MASK GDK_CONTROL_MASK
 #define LIVES_ALT_MASK     GDK_MOD1_MASK
 #define LIVES_SHIFT_MASK   GDK_SHIFT_MASK
 #define LIVES_LOCK_MASK    GDK_LOCK_MASK
 
+#define LIVES_BUTTON1_MASK    GDK_BUTTON1_MASK
+#define LIVES_BUTTON2_MASK    GDK_BUTTON2_MASK
+#define LIVES_BUTTON3_MASK    GDK_BUTTON3_MASK
+#define LIVES_BUTTON4_MASK    GDK_BUTTON4_MASK
+#define LIVES_BUTTON5_MASK    GDK_BUTTON5_MASK
+
 #ifdef GDK_KEY_a
 #define LIVES_KEY_Left GDK_KEY_Left
 #define LIVES_KEY_Right GDK_KEY_Right
